@@ -27,28 +27,10 @@ import numpy.typing as npt
 
 
 BLANK_TILE = 0
-Board: TypeAlias = npt.NDArray[np.unsignedinteger]
+Board: TypeAlias = npt.NDArray
 FrozenBoard: TypeAlias = tuple[tuple[int, ...], ...]
 
 
-def is_solved(board: Board) -> bool:
-    """
-    Determine if a board is in the solved state.
-
-    Args:
-        board: The board
-
-    Returns:
-        True if the board is solved, otherwise False.
-    """
-    h, w = board.shape
-    for y, row in enumerate(board):
-        for x, tile in enumerate(row):
-            if tile != get_goal_tile(h, w, (y, x)):
-                return False
-    return True
-
-
 def new_board(h: int, w: int, dtype: Optional[npt.DTypeLike] = None) -> Board:
     """
     Create a new board in the default solved state.
@@ -168,7 +150,7 @@ def freeze_board(board: Board) -> FrozenBoard:
     return tuple(tuple(row) for row in board)
 
 
-def print_board(board: Board | FrozenBoard, file=sys.stdout) -> Board:
+def print_board(board: Board | FrozenBoard, file=sys.stdout) -> Board | FrozenBoard:
     """
     Convienance function for printing a formatted board.
 
@@ -259,6 +241,24 @@ def get_goal_tile(h: int, w: int, pos: tuple[int, int]) -> int:
     return (w * pos[0]) + pos[1] + 1
 
 
+def is_solved(board: Board) -> bool:
+    """
+    Determine if a board is in the solved state.
+
+    Args:
+        board: The board
+
+    Returns:
+        True if the board is solved, otherwise False.
+    """
+    h, w = board.shape
+    for y, row in enumerate(board):
+        for x, tile in enumerate(row):
+            if tile != get_goal_tile(h, w, (y, x)):
+                return False
+    return True
+
+
 def find_tile(board: Board | FrozenBoard, tile: int) -> tuple[int, int]:
     """
     Given a tile number, find the (y, x)-coord on the board.
@@ -541,7 +541,7 @@ def visit(visited: set[FrozenBoard], board: Board) -> bool:
 
 def board_generator(h: int, w: int) -> Iterator[Board]:
     """
-    Returns a generator that yields all possible boards, in numerical order.
+    Returns a generator that yields all solvable boards in lexicographical order.
 
     Args:
         h: Height of board
@@ -550,6 +550,7 @@ def board_generator(h: int, w: int) -> Iterator[Board]:
     Yields:
         A board permutation
     """
-    size = h * w
-    for values in itertools.permutations(range(size)):
-        yield board_from_iter(h, w, values)
+    for values in itertools.permutations(range(h * w)):
+        board = board_from_iter(h, w, values)
+        if is_solvable(board):
+            yield board
